
#### Get PubChem CID ####

# install libraries

# load libraries
library(webchem)
library(reshape2)
#---------------------------------#
#read in metaboscape output
#---------------------------------#
dat <- read.csv(file.choose(), sep=",", header = T, stringsAsFactors = F, check.names = F)

# -------------------------------- #
# Get CIDs from molecule names ; credits to Linnea Catherine Smith for solving the curl issue
# -------------------------------- #
# Do it in chunks of 50 because for some reason when running the whole thing at once it gives the error: 
# "Error in curl::curl_fetch_memory(url, handle = handle) : 
#  Error in the HTTP2 framing layer"  but in smaller batches that doesn't happen

cid.from.name <- get_cid(dat$Name[1:50], from = "name", match = "first", verbose = T)
cid.from.name <- rbind(cid.from.name,get_cid(dat$Name[51:100], from = "name", match = "first", verbose = T))
for(i in seq(nrow(cid.from.name)+1,nrow(dat),by=50)){
  cid.from.name <- rbind(cid.from.name,get_cid(dat$Name[i:(i+49)], from = "name", match = "first", verbose = T))
  print(paste(i,"/",NROW(dat$Name),sep=""))
}
cid.from.name <- cid.from.name[1:nrow(dat),]
dat$CID.fromName <- cid.from.name$cid
sapply(dat, class)
write.csv(dat,"path/to/your/data.csv",row.names=F)

# ------------------------ #
# get inchikey and smiles from pubchem
# ------------------------ #

# read in or directly use data from previous step

pubchemlist <- dat$cid
pubchemlist <- trimws(pubchemlist)
prop_list <- pc_prop(pubchemlist, properties = c("InchiKey", "Inchi" ,"CanonicalSMILES"),verbose=T)
write.csv(prop_list, "path/to/your/data.csv",row.names=F)

############# Classyfire ##################
# read in from previous step

library(RAMClustR)

smiles_info <- getSmilesInchi(dat) # data table from previous step

# get rid of the list history if applicable
input <- smiles_info[-7]
classyfired <- getClassyFire(input, get.all = T, max.wait = 10, posts.per.minute = 5)
results <- subset(classyfired, select=c("cmpd.name", "CID", "inchikey", "smiles", "classyfire"))

#results[is.na(results)] <- 0
setwd(choose.dir())
write.csv(results, "path/to/your/data.csv",row.names=F)

# merging of classyfire output with original data table with merge function

# sum up intensities per group, done by hand

############ setup data for sunburst plots ###################



#install the packages if necessary
if(!require("tidyverse")) install.packages("tidyverse")
if(!require("fs")) install.packages("fs")
if(!require("readxl")) install.packages("readxl")
if(!require("writexl")) install.packages("writexl")

#load packages
library(tidyverse)
library(fs)
library(readxl)
library(writexl)

path <- choose.files()

mad <- path %>%
  excel_sheets() %>%
  set_names() %>%
  map(read_excel,
      path = path)

roots.sum <- aggregate(mad$`Cgla root`$`Summed up intensities`, 
                       by=list(classyfire.kingdom=mad$`Cgla root`$classyfire.kingdom,
                               classyfire.superclass=mad$`Cgla root`$classyfire.superclass,
                               classyfire.class=mad$`Cgla root`$classyfire.class), FUN=sum)
leaves.sum <- aggregate(mad$`Cgla leaf`$`Summed up intensities`, 
                        by=list(classyfire.kingdom=mad$`Cgla leaf`$classyfire.kingdom,
                                classyfire.superclass=mad$`Cgla leaf`$classyfire.superclass,
                                classyfire.class=mad$`Cgla leaf`$classyfire.class), FUN=sum)
exudate.sum <- aggregate(mad$`Cgla exudate`$`Summed up intensities`, 
                         by=list(classyfire.kingdom=mad$`Cgla exudate`$classyfire.kingdom,
                                 classyfire.superclass=mad$`Cgla exudate`$classyfire.superclass,
                                 classyfire.class=mad$`Cgla exudate`$classyfire.class), FUN=sum)

x <- list(exudate.sum, leaves.sum, roots.sum)
write_xlsx(x, path = "path/to/your/data.xlsx", col_names=T)